validate_state_write

Function validate_state_write 

pub fn validate_state_write(
    contract: &CapabilityContract,
    key: &str,
    value: &Value,
) -> Result<(), DataStoreError>
Validates a capability state write against the contract-declared state schema.

Errors

Returns DataStoreError when the key is invalid, the contract does not declare a state schema, the key is not declared by the schema, or the value does not match the declared key schema.