CheckpointStore

Trait CheckpointStore 

pub trait CheckpointStore {
    // Required methods
    fn save(
        &mut self,
        checkpoint: DurableCheckpoint,
    ) -> Result<(), DurableOrchestrationError>;
    fn load(
        &self,
        execution_id: &str,
    ) -> Result<Option<DurableCheckpoint>, DurableOrchestrationError>;
    fn verify(&self, checkpoint: &DurableCheckpoint) -> bool;
}
Host boundary for authenticated persistence. Implementations must keep signing material outside DurableCheckpoint and atomically replace by fencing token.

Required Methods

fn save( &mut self, checkpoint: DurableCheckpoint, ) -> Result<(), DurableOrchestrationError>

Errors

Returns a stable persistence failure when the host cannot atomically save.

fn load( &self, execution_id: &str, ) -> Result<Option<DurableCheckpoint>, DurableOrchestrationError>

Errors

Returns a stable host storage failure when loading cannot complete.

fn verify(&self, checkpoint: &DurableCheckpoint) -> bool

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors