pub struct EventCatalog { /* private fields */ }Expand description
Thread-safe registry of event types.
Implementations
Sourceimpl EventCatalog
impl EventCatalog
Sourcepub fn register(&self, entry: EventCatalogEntry) -> Result<(), EventError>
pub fn register(&self, entry: EventCatalogEntry) -> Result<(), EventError>
Register a new event type. Returns an error if the type is already registered.
Errors
Returns EventError::LifecycleViolation if event_type is already registered.
Sourcepub fn list(&self) -> Vec<EventCatalogEntry>
pub fn list(&self) -> Vec<EventCatalogEntry>
Return a snapshot of all entries.
Sourcepub fn get(&self, event_type: &str) -> Option<EventCatalogEntry>
pub fn get(&self, event_type: &str) -> Option<EventCatalogEntry>
Look up a single entry by event type.
Sourcepub fn increment_consumer_count(&self, event_type: &str)
pub fn increment_consumer_count(&self, event_type: &str)
Atomically increment the subscriber count for an event type.