Module executor

Module executor 

Capability executor abstraction for Traverse.

Governed by spec 025-wasm-executor-adapter.

Two concrete implementations:

  • NativeExecutor — executes capabilities implemented as native Rust closures.
  • WasmExecutor — executes capabilities compiled to wasm32-wasi binaries via Wasmtime when the wasmtime-executor feature is enabled.
  • ThreadPoolExecutor — dispatches native capability execution onto a bounded worker pool when the native-executors feature is enabled.

Re-exports

pub use native::NativeExecutor;
pub use thread_pool::ConfigError;
pub use thread_pool::ThreadPoolExecutor;
pub use thread_pool::ThreadPoolExecutorConfig;
pub use wasm::ActivatedConnector;
pub use wasm::ConnectorInvokeRequest;
pub use wasm::ConnectorInvokeResponse;
pub use wasm::HostAbiImport;
pub use wasm::HostAbiValidation;
pub use wasm::MediatedConnector;
pub use wasm::MediatedConnectorContext;
pub use wasm::SUPPORTED_HOST_ABI_VERSION;
pub use wasm::WasmBinaryCacheStats;
pub use wasm::WasmExecutionLimits;
pub use wasm::WasmExecutor;
pub use wasm::WasmModuleCacheConfig;
pub use wasm::WasmModuleCacheStats;
pub use wasm::supported_host_abi_versions;
pub use wasm::verify_wasm_host_abi_bytes;

Modules

native
Native (Rust closure) executor.
thread_pool
Bounded native capability executor.
wasm
Wasmtime-backed WASM executor.

Structs

ConnectorInvocationEvidence
Immutable, non-secret outcome evidence for one mediated connector call.
ExecutorCapability
A resolved capability ready for execution.
ExecutorOutput
Output of a CapabilityExecutor::execute call.

Enums

ArtifactType
The artifact type recorded in a capability registration, used to route to the correct executor.
ExecutorError
Error returned by a CapabilityExecutor.

Traits

CapabilityExecutor
Trait implemented by all capability executors.