pub struct EventMatchRecord {
pub event_id: String,
pub event_version: String,
pub edge_id: String,
pub match_result: EventMatchResult,
pub predicate_result: Option<EventPredicateResult>,
pub rejection_reason: Option<String>,
pub recorded_at: String,
pub subscription_id: Option<String>,
pub cursor: Option<String>,
}Fields
event_id: Stringevent_version: Stringedge_id: Stringmatch_result: EventMatchResultpredicate_result: Option<EventPredicateResult>rejection_reason: Option<String>recorded_at: Stringsubscription_id: Option<String>EventBroker subscription that sourced this event, None when the
event came from the current node’s own emitted output rather than
EventBroker (spec 099 FR-005).
cursor: Option<String>EventBroker cursor the event was delivered at, None for a
same-node emitted event (spec 099 FR-005).