pub struct RuntimeTrace {Show 20 fields
pub kind: String,
pub schema_version: String,
pub trace_id: String,
pub execution_id: String,
pub request_id: String,
pub governing_spec: String,
pub request: RuntimeRequest,
pub decision_evidence: TraceDecisionEvidence,
pub state_progression: TraceStateProgression,
pub terminal_outcome: TraceTerminalOutcome,
pub emitted_events: Vec<EventReference>,
pub workflow_evidence: Option<WorkflowTraversalEvidence>,
pub model_resolution: Vec<ModelResolutionEvidence>,
pub state_transitions: Vec<RuntimeTransitionRecord>,
pub state_machine_validation: RuntimeStateMachineValidationEvidence,
pub candidate_collection: CandidateCollectionRecord,
pub selection: SelectionRecord,
pub execution: ExecutionRecord,
pub result: TraceResultRecord,
pub otel_trace: OTelTraceRecord,
}Fields
kind: Stringschema_version: Stringtrace_id: Stringexecution_id: Stringrequest_id: Stringgoverning_spec: Stringrequest: RuntimeRequestdecision_evidence: TraceDecisionEvidencestate_progression: TraceStateProgressionterminal_outcome: TraceTerminalOutcomeemitted_events: Vec<EventReference>workflow_evidence: Option<WorkflowTraversalEvidence>model_resolution: Vec<ModelResolutionEvidence>state_transitions: Vec<RuntimeTransitionRecord>state_machine_validation: RuntimeStateMachineValidationEvidencecandidate_collection: CandidateCollectionRecordselection: SelectionRecordexecution: ExecutionRecordresult: TraceResultRecordotel_trace: OTelTraceRecordImplementations
Sourceimpl RuntimeTrace
impl RuntimeTrace
Sourcepub fn with_model_resolution(
self,
evidence: Vec<ModelResolutionEvidence>,
) -> Self
pub fn with_model_resolution( self, evidence: Vec<ModelResolutionEvidence>, ) -> Self
Returns a trace with synchronized public model resolution evidence.
Sourcepub fn selected_capability_id(&self) -> Option<&str>
pub fn selected_capability_id(&self) -> Option<&str>
Returns the ID of the selected capability, or None if no capability was selected.
Sourcepub fn errors(&self) -> Option<&RuntimeError>
pub fn errors(&self) -> Option<&RuntimeError>
Returns the error from the terminal outcome, or None if execution succeeded.
Sourcepub fn emitted_events(&self) -> &[EventReference]
pub fn emitted_events(&self) -> &[EventReference]
Returns all events emitted during execution.
Sourcepub fn output(&self) -> Option<&Value>
pub fn output(&self) -> Option<&Value>
Returns the output value produced by execution, or None if unavailable.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the execution completed successfully.