pub struct InProcessBroker { /* private fields */ }Expand description
Synchronous, in-memory implementation of EventBroker.
The broker stores a bounded retention buffer per event type and maintains a bounded delivery queue per subscription. Subscribers poll for events using a broker-issued subscription id and a cursor.
Implementations
Sourceimpl InProcessBroker
impl InProcessBroker
Sourcepub fn new(catalog: Arc<EventCatalog>) -> Result<Self, EventError>
pub fn new(catalog: Arc<EventCatalog>) -> Result<Self, EventError>
Create a new broker backed by the given catalog.
Errors
Returns EventError::InvalidRetentionWindow when the provided configuration is invalid.
Sourcepub fn with_clock(
catalog: Arc<EventCatalog>,
config: BrokerConfig,
clock: Arc<dyn BrokerClock>,
) -> Result<Self, EventError>
pub fn with_clock( catalog: Arc<EventCatalog>, config: BrokerConfig, clock: Arc<dyn BrokerClock>, ) -> Result<Self, EventError>
Create a broker with explicit configuration and clock.
Errors
Returns EventError::InvalidRetentionWindow when the provided configuration is invalid.