Capability executor abstraction for Traverse.
Governed by spec 025-wasm-executor-adapter.
Two concrete implementations:
NativeExecutor— executes capabilities implemented as native Rust closures.WasmExecutor— executes capabilities compiled towasm32-wasibinaries via Wasmtime when thewasmtime-executorfeature is enabled.ThreadPoolExecutor— dispatches native capability execution onto a bounded worker pool when thenative-executorsfeature is enabled.
Re-exports
pub use native::NativeExecutor;pub use thread_pool::ConfigError;pub use thread_pool::ThreadPoolExecutor;pub use thread_pool::ThreadPoolExecutorConfig;pub use wasm::HostAbiImport;pub use wasm::HostAbiValidation;pub use wasm::SUPPORTED_HOST_ABI_VERSION;pub use wasm::WasmExecutionLimits;pub use wasm::WasmExecutor;pub use wasm::WasmModuleCacheConfig;pub use wasm::WasmModuleCacheStats;pub use wasm::supported_host_abi_versions;pub use wasm::verify_wasm_host_abi_bytes;
Modules
- native
- Native (Rust closure) executor.
- thread_
pool - Bounded native capability executor.
- wasm
- Wasmtime-backed WASM executor.
Structs
- Executor
Capability - A resolved capability ready for execution.
- Executor
Output - Output of a
CapabilityExecutor::executecall.
Enums
- Artifact
Type - The artifact type recorded in a capability registration, used to route to the correct executor.
- Executor
Error - Error returned by a
CapabilityExecutor.
Traits
- Capability
Executor - Trait implemented by all capability executors.